pub struct StoryDisplayDescriptor {
pub source: StoryDisplaySource,
pub display_name: String,
pub story_title: Option<String>,
}Fields
source: StoryDisplaySourcedisplay_name: Stringstory_title: Option<String>Trait Implementations
Sourceimpl Clone for StoryDisplayDescriptor
impl Clone for StoryDisplayDescriptor
Sourcefn clone(&self) -> StoryDisplayDescriptor
fn clone(&self) -> StoryDisplayDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoryDisplayDescriptor
impl Debug for StoryDisplayDescriptor
Sourceimpl<'de> Deserialize<'de> for StoryDisplayDescriptor
impl<'de> Deserialize<'de> for StoryDisplayDescriptor
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<StoryDisplayDescriptor, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<StoryDisplayDescriptor, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for StoryDisplayDescriptor
Sourceimpl JsonSchema for StoryDisplayDescriptor
impl JsonSchema for StoryDisplayDescriptor
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StoryDisplayDescriptor
impl PartialEq for StoryDisplayDescriptor
Sourceimpl Serialize for StoryDisplayDescriptor
impl Serialize for StoryDisplayDescriptor
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for StoryDisplayDescriptor