pub fn with_current<T>(reader: impl FnOnce(&TraceState) -> T) -> Option<T>Expand description
Read the current trace state, if this task runs inside a trace bracket.
pub fn with_current<T>(reader: impl FnOnce(&TraceState) -> T) -> Option<T>Read the current trace state, if this task runs inside a trace bracket.